@@ -64,18 +64,17 @@ static int create_metadata_block_groups(struct btrfs_root *root, int mixed,
 	struct btrfs_fs_info *fs_info = root->fs_info;
 	struct btrfs_trans_handle *trans;
 	struct btrfs_space_info *sinfo;
+	u64 flags = BTRFS_BLOCK_GROUP_METADATA;
 	u64 bytes_used;
 	u64 chunk_start = 0;
 	u64 chunk_size = 0;
 	int ret;
 
+	if (mixed)
+		flags |= BTRFS_BLOCK_GROUP_DATA;
+
 	/* Create needed space info to trace extents reservation */
-	ret = update_space_info(fs_info, BTRFS_BLOCK_GROUP_METADATA,
-				0, 0, &sinfo);
-	if (ret < 0)
-		return ret;
-	ret = update_space_info(fs_info, BTRFS_BLOCK_GROUP_DATA,
-				0, 0, &sinfo);
+	ret = update_space_info(fs_info, flags, 0, 0, &sinfo);
 	if (ret < 0)
 		return ret;
 
@@ -149,6 +148,13 @@ static int create_data_block_groups(struct btrfs_trans_handle *trans,
 	int ret = 0;
 
 	if (!mixed) {
+		struct btrfs_space_info *sinfo;
+
+		ret = update_space_info(fs_info, BTRFS_BLOCK_GROUP_DATA,
+					0, 0, &sinfo);
+		if (ret < 0)
+			return ret;
+
 		ret = btrfs_alloc_chunk(trans, fs_info,
 					&chunk_start, &chunk_size,
 					BTRFS_BLOCK_GROUP_DATA);
