@@ -27,11 +27,11 @@
 #include <ftw.h>
 #include "ctree.h"
 #include "volumes.h"
-#include "internal.h"
+#include "common/internal.h"
 #include "disk-io.h"
-#include "messages.h"
+#include "common/messages.h"
 #include "transaction.h"
-#include "utils.h"
+#include "common/utils.h"
 #include "mkfs/rootdir.h"
 #include "mkfs/common.h"
 #include "send-utils.h"
