@@ -20,7 +20,7 @@
 #include <stdlib.h>
 #include <signal.h>
 #include "kerncompat.h"
-#include "radix-tree.h"
+#include "kernel-lib/radix-tree.h"
 #include "ctree.h"
 #include "disk-io.h"
 #include "print-tree.h"
@@ -380,6 +380,7 @@ int main(int ac, char **av)
 	}
 	printf("initial fill\n");
 	trans = btrfs_start_transaction(root, 1);
+	BUG_ON(IS_ERR(trans));
 	ret = fill_tree(trans, root, &radix, init_fill_count);
 	printf("starting run\n");
 	if (ret) {
