@@ -77,6 +77,9 @@ struct btrfs_fs_devices {
 	u64 latest_devid;
 	u64 latest_trans;
 	u64 lowest_devid;
+
+	u64 total_rw_bytes;
+
 	int latest_bdev;
 	int lowest_bdev;
 	struct list_head devices;
@@ -117,6 +120,11 @@ struct btrfs_raid_attr {
 	int tolerated_failures; /* max tolerated fail devs */
 	int devs_increment;	/* ndevs has to be a multiple of this */
 	int ncopies;		/* how many copies to data has */
+	int nparity;		/* number of stripes worth of bytes to store
+				 * parity information */
+	int mindev_error;	/* error code if min devs requisite is unmet */
+	const char raid_name[8]; /* name of the raid */
+	u64 bg_flag;		/* block group flag of the raid */
 };
 
 extern const struct btrfs_raid_attr btrfs_raid_array[BTRFS_NR_RAID_TYPES];
